#!/bin/bash
#
# Copyright (c) 2002 on behalf of the EU DataGrid Project: 
# The European Organization for Nuclear Research (CERN).
# Particle Physics and Astronomy Research Council (PPARC).
# All rights reserved.
# see LICENSE file for details
#
#
# Package  : edg-java-security
# Release  : 1.5.10
# Changelog:
#
#=================================================================

#
# This bash function sets up the Edg environment
#

function edg-env-func(){

    # The location of the standard EDG environment setup
    EDG_ENV=/etc/sysconfig/edg
    EDG_ENV_HOME=$HOME/.etc.sysconfig.edg
    
    #save the existing settings
    EDG_LOCATION_SAVE=$EDG_LOCATION
    EDG_LOCATION_VAR_SAVE=$EDG_LOCATION_VAR
    EDG_TMP_SAVE=$EDG_TMP
    X509_USER_CERT_SAVE=$X509_USER_CERT
    X509_USER_KEY_SAVE=$X509_USER_KEY
    GRIDMAP_SAVE=$GRIDMAP
    GRIDMAPDIR_SAVE=$GRIDMAPDIR


    # The location of the standard globus environment setup
    GLOBUS_ENV=/etc/sysconfig/globus

    # And the standard Globus environment
    if [ -r ${GLOBUS_ENV} ]; then
        source ${GLOBUS_ENV}
    fi

    # Check for Globus location, and set default if necessary
    if [ "x${GLOBUS_LOCATION}x" = xx ]; then
        GLOBUS_LOCATION=/opt/globus
    fi

    # Add the Globus libs to the default shared library path
    if [ x${LD_LIBRARY_PATH}x = xx ]; then
        export LD_LIBRARY_PATH=${GLOBUS_LOCATION}/lib:/usr/lib;
    else
        export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${GLOBUS_LOCATION}/lib:/usr/lib;
    fi


    # first use the system defaults
    if [ -r $EDG_ENV ] ; then
        source $EDG_ENV
    fi
    
    # then override with values from $HOME dir
    if [ -r $EDG_ENV_HOME ] ; then
        source $EDG_ENV_HOME
    fi

    # use values that were possibly set before script was run or the defaults if not set
    if [ "x${EDG_LOCATION_SAVE}x" != xx ]; then
        EDG_LOCATION=$EDG_LOCATION_SAVE
    else
        if [ "x${EDG_LOCATION}x" = xx ]; then
            echo Warning: EDG_LOCATION not set, neither is the system default set, using default /opt/edg
            EDG_LOCATION=/opt/edg
#        else
#            echo Warning: EDG_LOCATION not set, using system default ${EDG_LOCATION}
        fi
    fi

    if [ "x${EDG_LOCATION_VAR_SAVE}x" != xx ]; then
        EDG_LOCATION_VAR=$EDG_LOCATION_VAR_SAVE
    else
        if [ "x${EDG_LOCATION_VAR}x" = xx ]; then
            echo Warning: EDG_LOCATION_VAR not set, neither is the system default set, using default /opt/edg/var
            EDG_LOCATION_VAR=/opt/edg/var
#        else
#            echo Warning: EDG_LOCATION_VAR not set, using system default ${EDG_LOCATION_VAR}
        fi
    fi

    if [ "x${EDG_TMP_SAVE}x" != xx ]; then
        EDG_TMP=$EDG_TMP_SAVE
    else
        if [ "x${EDG_TMP}x" = xx ]; then
            echo Warning: EDG_TMP not set, neither is the system default set, using default /tmp
            EDG_TMP=/tmp
#        else
#            echo Warning: EDG_TMP not set, using system default ${EDG_TMP}
        fi
    fi

    if [ "x${X509_USER_CERT_SAVE}x" != xx ]; then
        X509_USER_CERT=$X509_USER_CERT_SAVE
    else
        if [ "x${X509_USER_CERT}x" = xx ]; then
#            echo Warning: X509_USER_CERT not set, neither is the system default set, using default /etc/grid-security/hostcert.pem
            X509_USER_CERT=/etc/grid-security/hostcert.pem
#        else
#            echo Warning: X509_USER_CERT not set, using system default ${X509_USER_CERT}
        fi
    fi

    if [ "x${X509_USER_KEY_SAVE}x" != xx ]; then
        X509_USER_KEY=$X509_USER_KEY_SAVE
    else
        if [ "x${X509_USER_KEY}x" = xx ]; then
#            echo Warning: X509_USER_KEY not set, neither is the system default set, using default /etc/grid-security/hostkey.pem
            X509_USER_KEY=/etc/grid-security/hostkey.pem
#        else
#            echo Warning: X509_USER_KEY not set, using system default ${X509_USER_KEY}
        fi
    fi

    if [ "x${GRIDMAP_SAVE}x" != xx ]; then
        GRIDMAP=$GRIDMAP_SAVE
    else
        if [ "x${GRIDMAP}x" = xx ]; then
#            echo Warning: GRIDMAP not set, neither is the system default set, using default /etc/grid-security/grid-mapfile
            GRIDMAP=/etc/grid-security/grid-mapfile
#        else
#            echo Warning: GRIDMAP not set, using system default ${GRIDMAP}
        fi
    fi

    if [ "x${GRIDMAPDIR_SAVE}x" != xx ]; then
        GRIDMAPDIR=$GRIDMAPDIR_SAVE
    else
        if [ "x${GRIDMAPDIR}x" = xx ]; then
#            echo Warning: GRIDMAPDIR not set, neither is the system default set, using default /etc/grid-security/gridmapdir
            GRIDMAPDIR=/etc/grid-security/gridmapdir
#        else
#            echo Warning: GRIDMAPDIR not set, using system default ${GRIDMAPDIR}
        fi
    fi

}

#
# This bash function sets up the Edg java environment
#

function edg-java-env-func(){

    # defaults for the security code
    CERTDIR=${X509_CERT_DIR-/etc/grid-security/certificates}

    PROXY=${X509_USER_PROXY-/tmp/x509up_u$UID}

    # if JAVA_HOME is not defined, it is provided by j2sdk_profile
    if [ -z "$JAVA_HOME" ] ; then
        if [ -f "/etc/java/java.conf" ] ; then
            source "/etc/java/java.conf"
        fi
    fi

    if [ -z "$JAVA_HOME" ] ; then
      echo "We cannot determine $JAVA_HOME. Please set it in your environment or put the line "
      echo "export JAVA_HOME=<path-to-java-home> "
      echo "into the file /etc/java/java.conf, replacing <path-to-java-home>"
      echo "with the correct location of your java distribution."
      exit 1
    fi

    #
    # setup the java command
    #
    if [ -z "$JAVACMD" ] ; then 
      if [ -n "$JAVA_HOME"  ] ; then
          JAVACMD="$JAVA_HOME/bin/java"
      else
        JAVACMD=java
      fi
    fi

    if [ ! -x "$JAVACMD" ] ; then
      echo "Error: JAVACMD or JAVA_HOME is not set correctly."
      echo " We cannot execute $JAVACMD"
      exit 1
    fi

}


#
# A generic bash function to setup the classpath
# INPUT_JAR_LIST is the list of jars to find
# OUTPUT_CLASSPATH is the resulting classpath
#
# Authors   : James Casey  <james.casey@cern.ch>
# Authors   : Peter Kunszt <peter.kunszt@cern.ch>
#       
# Version  : $Id$
#
# 

function edg-classpath-func(){

    if [ -z "$CLIENT_HOME" ] ; then

      ## resolve links - $0 may be a link to erm's home
      PRG=$0
      progname=`basename $0`
      saveddir=`pwd`

      # need this for relative symlinks
      cd `dirname $PRG`

      while [ -h "$PRG" ] ; do
        ls=`ls -ld "$PRG"`
        link=`expr "$ls" : '.*-> \(.*\)$'`
        if expr "$link" : '.*/.*' > /dev/null; then
            PRG="$link"
        else
            PRG="`dirname $PRG`/$link"
        fi
      done

      CLIENT_HOME=`dirname "$PRG"`/..

      # make it fully qualified
      cd $saveddir
      CLIENT_HOME=`cd "$CLIENT_HOME" && pwd`

      cd $saveddir
    fi

    # setup the class path
    # The path to the client jar, relative to EDG_LOCATION

    CLIENT_JAVA=${CLIENT_HOME}/share/java

    if [ ! -d ${CLIENT_JAVA} ] ; then
      CLIENT_JAVA=""
    fi

    if [ "${EDG_LOCATION}/share/java" = "${CLIENT_JAVA}" ] ; then
      CLIENT_JAVA=""
    fi

    # search for the jars in these locations

    search="$CLIENT_JAVA $EDG_LOCATION/share/java /usr/share/java"

    # now assemble the classpath
    jarlist=""
    for dir in $search
    do
      for file in "$dir"/*.jar
      do
      # if the directory is empty, then it will return the input string
      # this is stupid, so case for it
      if [ "$file" != "$dir/*.jar" ] ; then

         base=`basename $file`
         for j in $INPUT_JAR_LIST
         do
             if [ "$j" = "$base" ] ; then

                new="true";
                for haveit in $jarlist
                do
                    if [ "$j" = "$haveit" ] ; then
                       new="false"
                    fi
                done
                if [ "$new" = "true" ] ; then
                    jarlist="$jarlist $j"
                    OUTPUT_CLASSPATH="$file":"$OUTPUT_CLASSPATH"
                fi

             fi
         done
      fi
      done
    done

    # check whether we have all of them
    all=""
    for haveit in $jars
    do
       missing="true"
       for item in $INPUT_JAR_LIST
       do
          if [ "$item" = "$haveit" ] ; then
              missing="false"
          fi
       done
       if [ "$missing" = "true" ] ; then
          all="$all $haveit"
       fi
    done
    if [ ! -z "$all" ] ; then
        echo "Could not find dependencies:"
        echo $all
        exit 1
    fi

}

edg-env-func
edg-java-env-func

INPUT_JAR_LIST="edg-java-security.jar bcprov-jdk14.jar log4j.jar"

edg-classpath-func

"$JAVACMD" -DgridProxyFile=$PROXY -classpath "$OUTPUT_CLASSPATH" org.edg.security.trustmanager.tomcat.TryAuthentication "$@"
 
